 
/*
 * Copyright (c) 2012-2014 Wind River Systems, Inc.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <zephyr.h>
#include <logging/log.h>
#include <drivers/uart.h>

#include <fs/fs.h>
#include <fs/littlefs.h>
#include <storage/flash_map.h>
#include "wmbus.h"


LOG_MODULE_REGISTER(app);

#if (CONFIG_SPI_NOR - 0) || DT_NODE_HAS_STATUS(DT_INST(0, jedec_spi_nor), okay)
#define FLASH_DEVICE DT_LABEL(DT_INST(0, jedec_spi_nor))
#define FLASH_NAME "JEDEC SPI-NOR"
#elif (CONFIG_NORDIC_QSPI_NOR - 0) || DT_NODE_HAS_STATUS(DT_INST(0, nordic_qspi_nor), okay)
#define FLASH_DEVICE DT_LABEL(DT_INST(0, nordic_qspi_nor))
#define FLASH_NAME "JEDEC QSPI-NOR"
#else
#error Unsupported flash driver
#endif


void uart_init(const struct device *uart)
{
	
	int err;

	uart = device_get_binding(DT_LABEL(DT_NODELABEL(uart1)));
	__ASSERT(uart, "Failed to get the device");
	if (!uart) {
		LOG_INF("UART binding failed");
		return -ENXIO;
	}
	LOG_INF("UART binding with %s", uart->name);

	struct uart_config uart_conf = {
		.baudrate=9600,
		.data_bits=UART_CFG_DATA_BITS_8,
		.parity=UART_CFG_PARITY_NONE,
		.stop_bits=UART_CFG_STOP_BITS_1,
		//.flow_ctrl=UART_CFG_FLOW_CTRL_RTS_CTS,
		.flow_ctrl=UART_CFG_FLOW_CTRL_NONE,
	};
	err=uart_configure(uart, &uart_conf);
	if(err){
		LOG_INF("UART conifguration failed");
		return -ENXIO;
	}
}

K_THREAD_DEFINE(wmbus_rx_thread_id, WMBUS_THREAD_STACKSIZE, wmbus_rx_thread, NULL, NULL,
		NULL, WMBUS_THREAD_PRIORITY, 0, 0);
void main(void)
{
	const struct device *uart;
	int err;
	uint32_t tx_count = 0;
	k_msleep(1000);
	LOG_INF("Program started\n");
	uart_init(uart);
	LOG_INF("Uart Initialized sucessfully\n");
	memtis_init(uart);
	LOG_INF("Memtis Initialized sucessfully\n");
	while (1) {
		memtis_get_serial_number(uart);
		LOG_INF("data transmitted: %d", tx_count++);
		k_sleep(K_MSEC(2000));

		//uart_poll_out(uart, txbuf[0]);
		//k_sleep(K_MSEC(100));
	}
	
	
	
}